import pygame
import random as rnd

def set_ball_speed():
    ''' Setter en tilfeldig fart og retning oppover.
    Ballen går venstre/høyre (x) og oppover (y)'''
    x = rnd.uniform(-.5, +.5) # - venstre og + høyre 
    y = rnd.uniform(-.4, -.2) # alltid oppover   
    return {'x':x, 'y':y}

def plasser_ball():
    ''' Plasserer ballen over paddelen '''
    global ball_x, ball_y # Globale - ikke lokale - variable
    ball_x = paddle.get_rect(topleft=(paddle_x, paddle_y)).center[0]
    ball_y = paddle_y - ball.get_height()

''' HOUSEKEEPING '''
''' Skap vinduet (display) '''
pygame.init() # Initialiserer pygame
pygame.display.set_icon(pygame.image.load("Python_logo.png")) # Gir vinduet logo
pygame.display.set_caption("Paddle (bruk piltaster)") # Gir vinduet overskrift
vindu = pygame.display.set_mode((1000, 600),pygame.RESIZABLE ) # Størrelse, kan endres
bakgrunnsfarge = (128,128,128) # grå
vindu.fill(bakgrunnsfarge) # "Maler" over alt innhold

''' Skap og plasser en paddle '''
paddle_speed = 0.35 #Hastigheten paddelen rører seg med
paddle = pygame.image.load("paddle.png")
paddle_x = vindu.get_rect().center[0] - paddle.get_width() / 2
paddle_y = vindu.get_height() - paddle.get_height()
vindu.blit(paddle,(paddle_x,paddle_y))

''' Skap og plasser en ball '''
ball_speed = set_ball_speed()
ball = pygame.image.load("Python_logo_liten.png")
plasser_ball() 
vindu.blit(ball, (ball_x, ball_y))

''' Diverse '''
gameover = False
score = 0 # starter uten poeng
minfont = pygame.font.SysFont("monospace", 22) # font for skårtekst

''' HOVEDLØKKE '''
while not gameover:
    for event in pygame.event.get(): # Hent hendelsene
        if event.type == pygame.QUIT: # Brukeren  har klikket lukking av vinduet
            gameover = True
        if event.type == pygame.WINDOWRESIZED:
            paddle_x = vindu.get_rect().center[0] - paddle.get_width() / 2
            paddle_y = vindu.get_height() - paddle.get_height()
            plasser_ball()

    ''' Håndter piltaster høyre/venstre for paddelen '''
    keys = pygame.key.get_pressed() # Hent tastetrykkene
    ''' Handling avhenger av piltast som ble trykket ''' 
    if keys[pygame.K_LEFT] and paddle_x > 0: # Venstre pil trykket
        paddle_x -= paddle_speed
    if keys[pygame.K_RIGHT] and paddle_x + paddle.get_width() < vindu.get_width():
        paddle_x += paddle_speed

    ''' Håndterer ballen '''
    ball_x += ball_speed['x']
    ball_y += ball_speed['y']
    if ball_x <= 0 or ball_x >= vindu.get_width() - ball.get_width():
        ball_speed['x'] = - ball_speed['x'] # kollidert med vegg - snu!
    if ball_y <= 0:
        ball_speed['y'] = - ball_speed['y'] # kollidert med tak - snu!
    
    ''' Sjekk om ballen har gått ut '''
    if ball_y >= vindu.get_height(): # game over, ball ut under vinduet
        gameover = True
        print (chr(7)) # systemlyd ved tap
        pygame.event.wait() # vent på at bruker gjør noe, da avsluttes programmet

    ''' Sjekk om det er kollisjon ball/paddle '''
    if ball.get_rect(topleft=(ball_x, ball_y)).colliderect \
            (paddle.get_rect(topleft=(paddle_x, paddle_y))):
        ball_speed = set_ball_speed() # sett ny, tilfeldig retning/fart
        plasser_ball()
        score += 1 # nytt treff gir poeng

    '''Oppdater skjermen '''
    vindu.fill(bakgrunnsfarge) # Overskriver alt med skjermfargen
    vindu.blit(paddle,(paddle_x,paddle_y)) # Tegn paddelen på nytt, i ny posisjon
    vindu.blit(ball, (ball_x, ball_y)) # Tegn ballen på nytt, i ny posisjon
    skårtekst = minfont.render(f'Skår: {score}',True,(255,255,0))
    vindu.blit(skårtekst, (5, 10)) # Skriv skår på skjermen
    pygame.display.flip() # Vis skjermen


